T1 plugin for Quantiphyse
=========================

This plugin provides Bayesian modelling code for generating T1
maps from VFA MRI data

Quantiphyse and quantiphyse-fabber must be installed. To
install the plugin from PyPi use:

    pip install quantiphyse-t1

The plugin will then be available from within Quantiphyse

